from distutils.core import setup

setup(
    name='Jitbit-Helpdesk',
    version='0.1.29',
    packages=['jitbit-helpdesk',],
    license='MIT',
    long_description=open('README.txt').read(),
    author="Jitbit LP",
    author_email="info@jitbit.com",
    url="https://www.jitbit.com/helpdesk/",
    description="Jitbit Helpdesk Ticketing system plugin for your python webapp"
)